/*
 * database.hpp
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlitepp (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlitepp for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef COMMAND_HPP_
#define COMMAND_HPP_


#include "statement.hpp"


namespace sqlite
{


/**
 * The command class represents an SQL command. Since there is very little
 * difference between a command an a statement, it is basically a shim around
 * the statement class with the addition of an exec() method to execute the
 * command.
 */
class command
	:
	public statement
{
//______________________________________________________________________________
//                                                                 instantiation
public:

	/**
	 * Constructor that provides the SQL statement to execute
	 * @param sql an SQL statement in UTF-8
	 */
	command(
		database &database,
		const std::string &sql )
		:
		statement( database, sql )
	{ }

//______________________________________________________________________________
//                                                              public interface
public:

	/**
	 * Execute the command. This is the same as doing a step().
	 * @see sqlite3_step()
	 */
	inline int exec()
	{
		return step();
	}

};


}


#endif /* COMMAND_HPP_ */
