/*
 * transaction.cpp
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlitepp (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlitepp for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlitepp/transaction.hpp>
#include <sqlitepp/database.hpp>
#include <sqlitepp/exception.hpp>


sqlite::transaction::transaction(
	database &database )
	:
	_database( database )
{
	int error_code = _database.exec( "BEGIN" );
	if( error_code != SQLITE_OK ) throw sqlite_error( error_code );
}


sqlite::transaction::transaction(
	database &database,
	const std::string &begin_sql,
	const std::string &rollback_sql )
	:
	_database( database ),
	_rollback_sql( rollback_sql )
{
	int error_code = _database.exec( begin_sql );
	if( error_code != SQLITE_OK ) throw sqlite_error( error_code );
}


sqlite::transaction::~transaction() throw( )
{
	rollback();
}


void sqlite::transaction::commit()
{
	int error_code = _database.exec( "COMMIT" );
	if( error_code != SQLITE_OK ) throw sqlite_error( error_code );
}


void sqlite::transaction::rollback()
{
	int error_code = _database.exec(
		_rollback_sql.empty()? "ROLLBACK" : _rollback_sql );
	if( error_code != SQLITE_OK ) throw sqlite_error( error_code );
}


sqlite::exclusive_transaction::exclusive_transaction(
	database &database )
	:
	transaction( database, "BEGIN EXCLUSIVE" )
{
}
