/*
 * test-database.cpp
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of sqlitepp (hereafter referred to as "this program").
 * See http://www.waxworlds.org/edam/software/sqlitepp for more information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlitepp.hpp>
#include <boost/filesystem.hpp>


#define DBFILE "test.db"


int main()
{
	// delete any existing test database
	if( boost::filesystem::exists( DBFILE ) )
		boost::filesystem::remove( DBFILE );

	// open database
	sqlite::database db( DBFILE );

	// test basic statement, via command class
	sqlite::command c1( db,
		"CREATE TABLE pets ( "
			"name TEXT PRIMARY KEY, "
			"age INTEGER "
		")" );
	c1.step();

	// test statement bind() calls, via command
	sqlite::command c2( db, "INSERT INTO pets VALUES( ?, ? )" );
	c2.bind( 1, "billy" ); c2.bind( 2, 12 ); c2.exec();
	sqlite::command c3( db, "INSERT INTO pets VALUES( ?, ? )" );
	c3.bind( 2, 16 ); c3.bind( 1, "mopti" ); c3.exec();
	sqlite::command c6( db, "INSERT INTO pets VALUES( ?, ? )" );
	c6.bind_null( 1 ); c6.bind( 2, 123 ); c6.exec();

	// test binding via stream operator
	sqlite::command c4( db, "INSERT INTO pets VALUES( ?, ? )" );
	c4 << "tessa" << 16 << sqlite::exec;
	sqlite::command c5( db, "INSERT INTO pets VALUES( ?, ? )" );
	c5 << sqlite::null << sqlite::null <<
		sqlite::set_index( 1 ) << "tamara" << sqlite::exec;

	return 0;
}
